
logspace <- function (x1, x2, n = 100) 
{
    stopifnot(is.numeric(x1), is.numeric(x2), length(x1) == 1, 
        length(x2) == 1)
    n <- floor(n)
    if (n <= 1) 
        x2
    else seq(x1, x2, length.out = n)
}

computeDWT <- function(singleChannelSignal, tvec, srate=250, min_freq=2, max_freq=48, nfrex=30, n_cyc=5) { 
   n = length(tvec)
   wtime = seq(-2, 2, by=1/srate) #wavelet time
   halfwavL = floor(length(wtime)/2)
   
   Lconv = n + length(wtime)-1

   frex = seq(min_freq, max_freq, length.out=nfrex) 

   tf = matrix(0,nfrex, length(singleChannelSignal))
   # Need to explicitly pad the time series with zeros to get
   #  to desired length
   singleChannelSignalX = fft(c(singleChannelSignal, rep(0, Lconv-length(singleChannelSignal))))
   for(fi in 1:nfrex){
     w = 2*(n_cyc/(2*pi*frex[fi]))^2
     gauss_win = exp((-1*wtime^2/w))
     sine_wave = exp(1i*2*pi*frex[fi]*wtime)
     cmw = gauss_win*sine_wave
     cmwX = fft(c(cmw, rep(0, Lconv-length(cmw))))
     max.cmwX <- which(abs(cmwX)==max(abs(cmwX)))
     cmwX = cmwX/cmwX[max.cmwX] #scales to 1
     
     convres = fft(singleChannelSignalX*cmwX, inverse=TRUE)
     # inverse fft does not normalize by length in R
     convres <- convres / length(convres)
     
     tf[fi,] = 2*abs(convres[halfwavL:(length(convres)-halfwavL-1)])
     #Warning message:
     # longer object length is not a multiple of shorter object length
   }
   return(t(tf))
}
